import { buttonVariants } from "@/components/ui/button"
import { UserAvatar } from "@/components/user-avatar"
import { cn, formatTimeElapsed } from "@/lib/utils"
import Link from "next/link"
import { useRouter } from "next/navigation"
import { IGweet } from "../types"
import { GweetActions } from "./gweet-actions"
import { GweetMedia } from "./gweet-media"
import { GweetOptions } from "./gweet-options"

export const Gweet = ({ gweet }: { gweet: IGweet }) => {
    const router = useRouter()

    return (
        <div
            tabIndex={0}
            onClick={() => router.push(`/${gweet.author.username}/status/${gweet.id}`)}
            className={cn(buttonVariants({ variant: "ghost" }), "flex flex-col flex-grow h-auto w-full text-left cursor-pointer items-start p-3 space-y-3")}
        >
            {gweet?.replyToGweetId && (
                <div>
                    <span className="text-muted-foreground">Replying to </span>
                    <Link
                        href={`/${gweet?.comment.author.username}`}
                        className="text-sky-500 hover:underline z-10"
                        onClick={(e) => {
                            e.stopPropagation()
                        }}>
                        @{gweet?.comment.author.username}
                    </Link>
                </div>
            )}

            <div className="flex flex-row h-auto w-full">
                <Link
                    href={`/${gweet.author.username}`}
                    onClick={(e) => {
                        e.stopPropagation()
                    }}>
                    <UserAvatar
                        user={{ username: gweet.author.username, image: gweet.author.image }}
                        className="h-10 w-10"
                    />
                </Link>
                <div className="flex flex-col flex-grow space-y-3 ml-3 w-1">
                    <div className="flex items-start">

                        <div className="flex space-x-2 flex-grow">
                            <Link
                                className="flex space-x-2 hover:underline decoration-muted-foreground"
                                href={`/${gweet.author.username}`}
                                onClick={(e) => { e.stopPropagation() }}
                            >
                                <h1 className="font-bold">{gweet.author.name}</h1>
                                <h1 className="text-sky-500 text-sm">
                                    @{gweet.author.username}
                                </h1>
                            </Link>
                            <span>·</span>
                            <h1 className="text-gray-500 text-sm">
                                {formatTimeElapsed(gweet.createdAt)}
                            </h1>
                        </div>

                        <div className="ml-auto">
                            <GweetOptions gweet={gweet} />
                        </div>
                    </div>

                    <div className="flex flex-col flex-grow space-y-3 w-full">
                        {gweet.content && <h1 className="break-words">{gweet.content}</h1>}

                        {gweet.media.length > 0 && (<GweetMedia gweet={gweet} />)}

                        {/* TODO */}
                        {/* {quoted_gweet && <QuotedGweet gweet={quoted_gweet} />} */}
                    </div>
                </div>
            </div>

            <div className="flex justify-end flex-grow w-full" >
                <GweetActions gweet={gweet} />
            </div>
        </div>
    )
}